//--------------------------------------------------------------
// File     : stm32_ub_http_server.c
// Datum    : 14.02.2016
// Version  : 1.0
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : STM32F746
// IDE      : OpenSTM32
// GCC      : 4.9 2015q2
// Module   : CubeHAL
// Funktion : Ethernet HTTP-Server (per PHY : LAN8742A-CZ)
//            IP-Stack = lwIP (V:1.4.1)
//
// Hinweis  : benutzt wird die RMII-Schnittstelle
//
//            PA1  = RMII_Ref_Clk       PC1 = ETH_MDC
//            PA2  = ETH_MDIO           PC4 = RMII_RXD0
//            PA7  = RMII_CRS_DV        PC5 = RMII_RXD1
//            PG11 = RMII_TX_EN
//            PG13 = RMII_TXD0          NRST = Reset
//            PG14 = RMII_TXD1
//
//--------------------------------------------------------------
// set include path to :
//   ${ProjDirPath}/http_server/stm_lolevel
//   ${ProjDirPath}/http_server/lwip_lolevel/system
//   ${ProjDirPath}/http_server/lwip_lolevel/src/include
//   ${ProjDirPath}/http_server/lwip_lolevel/src/include/ipv4
// set source location to :
//   /http_server
//--------------------------------------------------------------
// Webseite : Die HTML-Webseiten wurde mit dem Programm
//            "makefsdata.exe" in ein C-File umgewandelt
//            und im Projekt als "fsdata.c" im Flash gespeichert
//            => diese File darf NICHT mitcompiliert werden !!
//
// CGI      : die CGI-Funktionen werden im File
//            "httpd_cgi_ssi.c" freigegeben und programmiert
//--------------------------------------------------------------

//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32_ub_http_server.h"


//--------------------------------------------------------------
// Globale Variabeln
//--------------------------------------------------------------
extern struct netif gnetif;



//--------------------------------------------------------------
// interne Funktionen
//--------------------------------------------------------------
void User_notification(struct netif *netif);


//--------------------------------------------------------------
// Init vom HTTP Server
// Return wert :
//      HTTP_INIT_OK => Server wurde initialisiert
//   != HTTP_INIT_OK => Fehler, Server wurde nicht initialisiert
//--------------------------------------------------------------
HTTP_INIT_STATUS_t UB_HTTP_Server_Init(void)
{
  HTTP_INIT_STATUS_t ret_wert=HTTP_INIT_OK;

  // Ethernet + LWIP-Stack init
  MX_LWIP_Init();

  // HTTP init;
  httpd_init();

  // NVIC init
  HAL_NVIC_SetPriorityGrouping(NVIC_PRIORITYGROUP_4);
  HAL_NVIC_SetPriority(SysTick_IRQn, 0, 0);

  // Notify user
  User_notification(&gnetif);

  return(ret_wert);
}

//--------------------------------------------------------------
// HTTP Server
// diese Funktion muss zyklisch aufgerufen werden
//--------------------------------------------------------------
void UB_HTTP_Server_Do(void)
{
  // LwIP zyklisch aufrufen
  ethernetif_input(&gnetif);
  sys_check_timeouts();


#ifdef USE_DHCP
  /* handle periodic timers for DHCP */
  DHCP_Periodic_Handle(&gnetif);
#endif

}




//--------------------------------------------------------------
void User_notification(struct netif *netif)
{
  if (netif_is_up(netif)) {
    // success
  }
  else {
    // error
  }
}

//--------------------------------------------------------------
void ethernetif_notify_conn_changed(struct netif *netif)
{
  if (netif_is_link_up(netif)) {
    // link up
    netif_set_up(netif);
  }
  else {
    // link down
    netif_set_down(netif);
  }
}





